

def list(survey_id, *args, **kwargs):
    """ Get list of all pages for a survey.

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveypage" % survey_id
    params = {

    }.update(kwargs)
    return tail, params


def get(survey_id, page_id, *args, **kwargs):
    """ Get surveypage by id.

        Required params:
        - survey_id:    survey ID
        - page_id:      page ID
    """
    tail = "survey/%s/surveypage/%s" % (survey_id, page_id)
    params = {

    }.update(kwargs)
    return tail, params


def create(survey_id, *args, **kwargs):
    """ Create new surveypage object.

        Required params:
        - survey_id:    survey ID

        Optional params:
        - after:        which page to add after
        - title:        page title
        - description:  page description
        - properties
    """
    tail = "survey/%s/surveypage" % survey_id
    params = {
        '_method': 'PUT',
    }.update(kwargs)
    return tail, params


def delete(survey_id, page_id, *args, **kwargs):
    """ Delete surveypage object.

        Required params:
        - survey_id:    survey ID
        - page_id:      page ID
    """
    tail = "survey/%s/surveypage/%s" % (survey_id, page_id)
    params = {
        '_method': 'DELETE',
    }.update(kwargs)
    return tail, params


def change(survey_id, page_id, *args, **kwargs):
    """ Change existing surveypage object.

        Required params:
        - survey_id:    survey ID
        - page_id:      page ID

        Optional params:
        - title:        page title
        - description:  page description
        - properties
    """
    tail = "survey/%s/surveypage/%s" % (survey_id, page_id)
    params = {
        '_method': 'POST',
    }.update(kwargs)
    return tail, params





def list(survey_id, *args, **kwargs):
    """ Get list of all statistics for a survey.

        Required params:
        - survey_id:    survey ID

        Optional params:
        - surveypage:       restricts the statistics to specific page
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveystatistic" % survey_id
    params = {

    }
    params.update(kwargs)
    return tail, params


def get(survey_id, statistic_id, *args, **kwargs):
    """ Get surveystatistic by id.

        Note: Experimental in SG

        Required params:
        - survey_id:    survey ID
        - statistic_id:  statistic ID
    """
    tail = "survey/%s/surveystatistic/%s" % (survey_id, statistic_id)
    params = {

    }
    params.update(kwargs)
    return tail, params





def list(*args, **kwargs):
    """ Get list of all account teams.

        Optional params:
        - showdeleted:      include deleted accountteams
        - page:             page number
        - resultsperpage:   number of results per page
    """
    return "accountteams/", {}


def get(accountteams_id, *args, **kwargs):
    """ Get account teams by id.

        Required params:
        - accountteams_id:    account teams ID
    """
    tail = "accountteams/%s" % accountteams_id
    params = {

    }
    params.update(kwargs)
    return tail, params


def create(*args, **kwargs):
    """ Create new accountteams object.

        Optional params:
        - teamname:         team name
        - description:      team description
        - color:            team color #FF00FF
        - defaultrole:      2 - 6 (ID of role)
    """
    tail = "accountteams/"
    params = {
        '_method': 'PUT',
    }
    params.update(kwargs)
    return tail, params


def change(accountteams_id, *args, **kwargs):
    """ Change existing accountteams object.

        Required params:
        - accountteams_id:  accountteams ID

        Optional params:
        - teamname:         team name
        - description:      team description
        - color:            team color #FF00FF
        - defaultrole:      2 - 6 (ID of role)
    """
    tail = "accountteams/%s" % accountteams_id
    params = {
        '_method': 'POST',
    }
    params.update(kwargs)
    return tail, params


def copy(accountteams_id, *args, **kwargs):
    """ Copy new account teams object from existing account teams.

        Required params:
        - accountteams_id:  account teams ID

        Optional params:
        - teamname:         team name
        - description:      team description
        - color:            team color #FF00FF
        - defaultrole:      2 - 6 (ID of role)
    """
    tail = "accountteams/%s" % accountteams_id
    params = {
        '_method': 'POST',
        'copy': 'true',
    }
    params.update(kwargs)
    return tail, params


def delete(accountteams_id, *args, **kwargs):
    """ Delete account teams object.

        Required params:
        - accountteams_id:       accountteams ID
    """
    tail = "accountteams/%s" % accountteams_id
    params = {
        '_method': 'DELETE',
    }
    params.update(kwargs)
    return tail, params





def list(survey_id, *args, **kwargs):
    """ Get list of all questions for a survey.

        Required params:
        - survey_id:    survey ID

        Optional params:
        - page:             page number
        - resultsperpage:   number of results per page
    """
    tail = "survey/%s/surveyquestion" % survey_id
    params = {

    }.update(kwargs)
    return tail, params


def get(survey_id, question_id, *args, **kwargs):
    """ Get surveyquestion by id.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID
    """
    tail = "survey/%s/surveyquestion/%s" % (survey_id, question_id)
    params = {

    }.update(kwargs)
    return tail, params


def create(survey_id, question_type, *args, **kwargs):
    """ Create new surveyquestion object.

        Required params:
        - survey_id:        survey ID
        - question_type:    select from [radio, text, email, checkbox, essay,
                                contsum, rank-dragdrop, multitext, hidden,
                                instructions, urlredirect, media, email, file,
                                single-image, multi-image]

        Optional params:
        - after:        which question to add after
        - title:        question title
        - description:  question description
        - properties
    """
    tail = "survey/%s/surveyquestion" % survey_id
    params = {
        '_method': 'PUT',
    }.update(kwargs)
    return tail, params


def delete(survey_id, question_id, *args, **kwargs):
    """ Delete surveyquestion object.

        Required params:
        - survey_id: survey ID
        - question_id:  question ID
    """
    tail = "survey/%s/surveyquestion/%s" % (survey_id, question_id)
    params = {
        '_method': 'DELETE',
    }.update(kwargs)
    return tail, params


def change(survey_id, question_id, *args, **kwargs):
    """ Change existing surveyquestion object.

        Required params:
        - survey_id:    survey ID
        - question_id:  question ID

        Optional params:
        - title:        question title
        - description:  question description
        - properties
    """
    tail = "survey/%s/surveyquestion/%s" % (survey_id, question_id)
    params = {
        '_method': 'POST',
    }.update(kwargs)
    return tail, params
